"""练习1，函数定义"""
def print_lol(the_list, level=0):
 """列表打印函数"""
 for each_item in the_list:
  if isinstance(each_item, list):
   print_lol(each_item, level)
  else:
   for tab_stop in range(level+1):
    print("\t",end='')
   print(each_item)



from distutils.core import setup

setup(
    name='jetdc-neaster',
    version='1.1.0',
    py_modules=['jetdc-neaster'],
    author='jetdc',
    author_email='jetdc@163.com',
    url='http://www.163.com',
    description='just for test',
    )
